@@ -24,6 +24,6 @@ XZ_OPT=--best tar -c -v -J -f $TAR \
     --exclude '*.nuspec' \
     --exclude '*.ps1' \
     --exclude '*.jar' \
-    --exclude '.travis.yml' \
+    --exclude '.travis*' \
     $DIR
 rm -rf $DIR
